@@ -581,6 +581,7 @@ class Plan(HeadersMixin):
                             wait_for=build.uid,
                             command=test.get("commands", []),
                             qemu_image=test.get("qemu_image"),
+                            tuxbuild=test.get("tuxbuild"),
                         )
                     )
                 self.builds.append(build)
@@ -612,6 +613,7 @@ class Plan(HeadersMixin):
                             callback=test.get("callback"),
                             command=test.get("commands", []),
                             qemu_image=test.get("qemu_image"),
+                            tuxbuild=test.get("tuxbuild"),
                         )
                     )
 
@@ -903,6 +905,7 @@ class Test(HeadersMixin):
     callback = attrib(default=None)
     command = attrib(default=[])
     qemu_image = attrib(default=None)
+    tuxbuild = attrib(default=None)
 
     uid = attrib(default=None)
     wait_for = attrib(default=None)
@@ -947,6 +950,8 @@ class Test(HeadersMixin):
             data["command"] = self.command
         if self.qemu_image:
             data["qemu_image"] = self.qemu_image
+        if self.tuxbuild:
+            data["tuxbuild"] = self.tuxbuild
         if plan is not None:
             data["plan"] = plan
 
