@@ -16,6 +16,7 @@ from tuxsuite.cli.utils import (
     error,
     format_result,
     show_log,
+    is_url,
 )
 
 import json
@@ -314,6 +315,7 @@ def handle_submit(cmdargs, _, config):
             build_name=cmdargs.build_name,
             no_cache=cmdargs.no_cache,
             is_public=cmdargs.private,
+            callback=cmdargs.callback,
         )
 
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
@@ -448,6 +450,16 @@ def build_cmd_options(sp):
         default=None,
         help="Pin the container image sha (64 hexadecimal digits)",
     )
+    sp.add_argument(
+        "--callback",
+        default=None,
+        help=(
+            "Callback URL. The kernel build backend will send a POST "
+            "request to this URL with signed data, when the kernel "
+            "build completes."
+        ),
+        type=is_url,
+    )
 
 
 def setup_parser(parser):
