@@ -317,6 +317,7 @@ def handle_submit(cmdargs, _, config):
             callback=cmdargs.callback,
             command=cmdargs.commands,
             qemu_image=cmdargs.qemu_image,
+            tuxbuild=cmdargs.tuxbuild,
         )
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
         error(e)
@@ -484,6 +485,13 @@ def test_cmd_options(sp):
         default=None,
         help="Use qemu from the given container image",
     )
+    sp.add_argument(
+        "--tuxbuild",
+        metavar="URL",
+        default=None,
+        help="URL of a TuxBuild build",
+        type=is_url,
+    )
 
 
 def setup_parser(parser):
